CacheConfig class

Constructors

CacheConfig({Duration ttl = const Duration(minutes: 5), Duration staleTtl = const Duration(hours: 1), bool enabled = true})

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staleTtl Duration
final
ttl Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited